using System;
using ThinkGeo.MapSuite.Core;
using PdfSharp.Pdf;
using System.Collections.ObjectModel;

namespace CSSamples.Samples
{
    public partial class DisplayASimpleMap : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-140, 60, 140, -60);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/world/cntry02.shp"));
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 243, 239, 228), GeoColor.FromArgb(255, 218, 193, 163), 1);
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                GdiPlusRasterLayer gdiPlusImageLayer = new GdiPlusRasterLayer(MapPath(@"~\SampleData\World\World.tif"));
                gdiPlusImageLayer.UpperThreshold = double.MaxValue;
                gdiPlusImageLayer.LowerThreshold = 0;

                Map1.StaticOverlay.Layers.Add(worldLayer);
                Map1.StaticOverlay.Layers.Add(gdiPlusImageLayer);
            }
        }

        protected void Button1_Click(object sender, EventArgs e)
        {
            ShapeFileFeatureLayer worldLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers[0];
            GdiPlusRasterLayer rasterLayer = (GdiPlusRasterLayer)Map1.StaticOverlay.Layers[1];

            PdfDocument doc = new PdfDocument();
            PdfPage page = doc.AddPage();
            page.Width = 800;
            page.Height = 800;

            double resolution = Math.Max(Map1.CurrentExtent.Width / Map1.Width.Value, Map1.CurrentExtent.Height / Map1.Height.Value);
            RectangleShape newDrawingExtent = new RectangleShape(Map1.CurrentExtent.UpperLeftPoint.X, Map1.CurrentExtent.UpperLeftPoint.Y, Map1.CurrentExtent.UpperLeftPoint.X + 800 * resolution, Map1.CurrentExtent.UpperLeftPoint.Y - 800 * resolution);
            PdfGeoCanvas canvas = new PdfGeoCanvas();
            canvas.BeginDrawing(page, newDrawingExtent, GeographyUnit.DecimalDegree);
            worldLayer.Open();
            worldLayer.Draw(canvas, new Collection<SimpleCandidate>() { });
            worldLayer.Close();
            canvas.EndDrawing();

            canvas.DrawingArea = new System.Drawing.Rectangle(0, 0, 400, 400);
            canvas.BeginDrawing(page, Map1.CurrentExtent, GeographyUnit.DecimalDegree);
            rasterLayer.Open();
            rasterLayer.Draw(canvas, new Collection<SimpleCandidate>() { });
            rasterLayer.Close();
            canvas.EndDrawing();
            doc.Save("c:\\1.pdf");
        }
    }
}
